@@ -3,6 +3,7 @@
 import asyncio
 import logging
 import signal
+import sys
 from pathlib import Path
 from typing import Optional
 
@@ -11,9 +12,11 @@ from rich.console import Console
 from rich.logging import RichHandler
 from rich.table import Table
 
+from .commands import audit as audit_cmd
 from .commands import custom_agents as custom_agents_cmd
 from .commands import feedback as feedback_cmd
 from .commands import summary as summary_cmd
+from .commands import telemetry as telemetry_cmd
 from devloop.agents import (
     AgentHealthMonitorAgent,
     FormatterAgent,
@@ -43,6 +46,34 @@ console = Console()
 app.add_typer(summary_cmd.app, name="summary")
 app.add_typer(custom_agents_cmd.app, name="custom")
 app.add_typer(feedback_cmd.app, name="feedback")
+app.add_typer(telemetry_cmd.app, name="telemetry")
+
+# Wrap Typer app to handle Click-based audit command
+# Note: We can't use add_typer with Click groups due to Typer version compatibility
+_original_app = app
+
+
+class _WrappedApp:
+    """Wrapper app that intercepts Click commands before Typer processes them."""
+
+    def __init__(self, typer_app):
+        self.typer_app = typer_app
+
+    def __call__(self, *args, **kwargs):
+        """Handle command invocation."""
+        if len(sys.argv) > 1 and sys.argv[1] == "audit":
+            # Delegate to Click for audit command
+            audit_cmd.audit(sys.argv[2:], standalone_mode=False)
+            return
+        # Otherwise, run the Typer app normally
+        return self.typer_app(*args, **kwargs)
+
+    def __getattr__(self, name):
+        """Delegate attribute access to the wrapped Typer app."""
+        return getattr(self.typer_app, name)
+
+
+app = _WrappedApp(_original_app)
 
 
 @app.command()
@@ -69,7 +100,7 @@ def amp_context():
     from pathlib import Path
 
     # Try to read the context index
-    context_dir = Path(".devloop/context")
+    context_dir = Path.cwd() / ".devloop/context"
     index_file = context_dir / "index.json"
 
     if index_file.exists():
@@ -228,35 +259,41 @@ def watch(
         console.print("\n[yellow]Shutting down...[/yellow]")
 
 
-async def _cleanup_old_data(context_store, event_store, interval_hours: int = 1):
-    """Periodically clean up old findings and events to prevent disk fill-up.
+async def _cleanup_old_data(context_store, event_store, interval_minutes: int = 15):
+    """Periodically clean up old findings and events to prevent disk/memory fill-up.
 
     Args:
         context_store: Context store instance
         event_store: Event store instance
-        interval_hours: How often to run cleanup (default: 1 hour)
+        interval_minutes: How often to run cleanup (default: 15 minutes)
+
+    Note: This is aggressive cleanup to prevent memory bloat between finds.
+    Most findings are auto-retained for 24 hours (IMMEDIATE/RELEVANT) or
+    7 days (BACKGROUND) on disk. Memory is trimmed more aggressively per
+    tier limits in ContextStore.add_finding().
     """
-    cleanup_interval = interval_hours * 60 * 60  # Convert to seconds
-    context_retention_hours = 7 * 24  # Keep 7 days of findings
+    cleanup_interval = interval_minutes * 60  # Convert to seconds
+    context_retention_hours = 7 * 24  # Keep 7 days of findings on disk
     event_retention_days = 30  # Keep 30 days of events
 
     while True:
         try:
             await asyncio.sleep(cleanup_interval)
 
-            # Clean up old context findings
+            # Clean up old context findings (removes from disk)
             findings_removed = await context_store.cleanup_old_findings(
                 hours_to_keep=context_retention_hours
             )
 
-            # Clean up old events
+            # Clean up old events (removes from database)
             events_removed = await event_store.cleanup_old_events(
                 days_to_keep=event_retention_days
             )
 
-            console.print(
-                f"[dim]Cleanup: removed {findings_removed} old findings, {events_removed} old events[/dim]"
-            )
+            if findings_removed > 0 or events_removed > 0:
+                console.print(
+                    f"[dim]Cleanup: removed {findings_removed} old findings, {events_removed} old events[/dim]"
+                )
 
         except asyncio.CancelledError:
             break
@@ -289,8 +326,13 @@ async def watch_async(path: Path, config_path: Path | None):
     console.print(f"[dim]Context store: {context_store.context_dir}[/dim]")
     console.print(f"[dim]Event store: {event_store.db_path}[/dim]")
 
-    # Create agent manager with project directory
-    agent_manager = AgentManager(event_bus, project_dir=path)
+    # Get global config for resource limits
+    global_config = config.get_global_config()
+
+    # Create agent manager with project directory and resource limits
+    agent_manager = AgentManager(
+        event_bus, project_dir=path, resource_limits=global_config.resource_limits
+    )
 
     # Create filesystem collector
     fs_config = {"watch_paths": [str(path)]}
@@ -558,10 +600,47 @@ This project uses background agents and Beads for task management.
                 commands_copied.append(template_file.stem)
 
         if commands_copied:
-            console.print(f"\n[green]✓[/green] Created Claude Code slash commands:")
+            console.print("\n[green]✓[/green] Created Claude Code slash commands:")
             for cmd in commands_copied:
                 console.print(f"  • /{cmd}")
 
+    # Install git hooks if this is a git repository
+    git_dir = path / ".git"
+    if git_dir.exists() and git_dir.is_dir():
+        # Check prerequisites before installing hooks
+        from devloop.cli.prerequisites import PrerequisiteChecker
+
+        checker = PrerequisiteChecker()
+        available, missing = checker.validate_for_git_hooks(interactive=True)
+
+        hooks_template_dir = Path(__file__).parent / "templates" / "git_hooks"
+        hooks_dest_dir = git_dir / "hooks"
+
+        if hooks_template_dir.exists():
+            hooks_installed = []
+            for template_file in hooks_template_dir.iterdir():
+                if template_file.is_file():
+                    dest_file = hooks_dest_dir / template_file.name
+
+                    # Backup existing hook if present
+                    if dest_file.exists():
+                        backup_file = hooks_dest_dir / f"{template_file.name}.backup"
+                        shutil.copy2(dest_file, backup_file)
+
+                    # Install new hook
+                    shutil.copy2(template_file, dest_file)
+                    dest_file.chmod(0o755)  # Make executable
+                    hooks_installed.append(template_file.name)
+
+            if hooks_installed:
+                console.print("\n[green]✓[/green] Installed git hooks:")
+                for hook in hooks_installed:
+                    console.print(f"  • {hook}")
+
+            # Show installation guide if prerequisites missing
+            if missing:
+                checker.show_installation_guide(missing)
+
     console.print("\n[green]✓[/green] Initialized!")
     console.print("\nNext steps:")
     console.print(f"  1. Review/edit: [cyan]{claude_dir / 'agents.json'}[/cyan]")
@@ -633,5 +712,54 @@ def version():
     console.print(f"DevLoop v{__version__}")
 
 
+@app.command()
+def update_hooks(path: Path = typer.Argument(Path.cwd(), help="Project directory")):
+    """Update git hooks from latest templates."""
+    import shutil
+
+    git_dir = path / ".git"
+
+    if not git_dir.exists() or not git_dir.is_dir():
+        console.print(
+            f"[red]✗[/red] Not a git repository: {path}\n"
+            "[yellow]Git hooks can only be installed in git repositories.[/yellow]"
+        )
+        return
+
+    hooks_template_dir = Path(__file__).parent / "templates" / "git_hooks"
+    hooks_dest_dir = git_dir / "hooks"
+
+    if not hooks_template_dir.exists():
+        console.print(f"[red]✗[/red] Hook templates not found at: {hooks_template_dir}")
+        return
+
+    hooks_dest_dir.mkdir(parents=True, exist_ok=True)
+    hooks_updated = []
+
+    for template_file in hooks_template_dir.iterdir():
+        if template_file.is_file():
+            dest_file = hooks_dest_dir / template_file.name
+
+            # Backup existing hook if present
+            if dest_file.exists():
+                backup_file = hooks_dest_dir / f"{template_file.name}.backup"
+                shutil.copy2(dest_file, backup_file)
+                console.print(
+                    f"[dim]  Backed up existing hook: {template_file.name} -> {template_file.name}.backup[/dim]"
+                )
+
+            # Install new hook
+            shutil.copy2(template_file, dest_file)
+            dest_file.chmod(0o755)  # Make executable
+            hooks_updated.append(template_file.name)
+
+    if hooks_updated:
+        console.print("\n[green]✓[/green] Updated git hooks:")
+        for hook in hooks_updated:
+            console.print(f"  • {hook}")
+    else:
+        console.print("[yellow]No hooks found to update[/yellow]")
+
+
 if __name__ == "__main__":
     app()
